Please submit help issues to:
https://matsci.org/c/matminer/16

The Github issues is no longer used except for internal development purposes.

If you are unable to use the Discourse forum, you may submit an issue here, but you must **clearly** state the reason you are unable to use the Discourse forum in your ticket. Otherwise, your issue will be **closed** without response.

Please search both the forums and former GitHub issues before raising a ticket to avoid duplicating discussions.
